%bcond_without  server

%define status stable
%define uversion %{version}-%{status}

Name:           godot
Version:        2.1.3
Release:        %mkrel 1
Summary:        Multi-platform 2D and 3D game engine with a feature rich editor
Group:          Development/Tools
License:        MIT
URL:            https://godotengine.org
Source0:        https://github.com/godotengine/godot/archive/%{uversion}/%{name}-%{uversion}.tar.gz
Source1:        https://github.com/godotengine/godot-demo-projects/archive/%{uversion}/godot-demo-projects-%{uversion}.tar.gz

ExclusiveArch:  %ix86 x86_64

BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(opusfile)
BuildRequires:  pkgconfig(theora)
BuildRequires:  pkgconfig(udev)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(vorbisfile)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  scons
Recommends:     %{name}-demos

%description
Godot is an advanced, feature packed, multi-platform 2D and 3D game engine.
It provides a huge set of common tools, so you can just focus on making
your game without reinventing the wheel.

Godot is completely free and open source under the very permissive MIT
license. No strings attached, no royalties, nothing. Your game is yours,
down to the last line of engine code.

%files
%doc LICENSE.md README.md
%{_bindir}/%{name}
%dir %{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/scalable/apps/%{name}.svg

#----------------------------------------------------------------------

%package        demos
Summary:        Demo projects to learn how to use Godot Engine
BuildArch:      noarch

%description    demos
This package contains the official demo projects to help new users to learn
the features of the game engine.

%files          demos
%{_datadir}/%{name}/demos/

#----------------------------------------------------------------------

%if %{with server}
%package        server
Summary:        Godot headless binary for servers
Group:          Games/Other

%description    server
This package contains the headless binary for the Godot game engine,
particularly suited for running dedicated servers.

%files          server
%{_bindir}/%{name}-server
%endif

#----------------------------------------------------------------------

%package        runner
Summary:        Shared binary to play games developed with the Godot engine
Group:          Games/Other

%description    runner
This package contains a godot-runner binary for the Linux X11 platform,
which can be used to run any game developed with the Godot engine simply
by pointing to the location of the game's data package.

%files          runner
%doc LICENSE.md README.md
%{_bindir}/%{name}-runner

#----------------------------------------------------------------------

%prep
%autosetup -p1 -n %{name}-%{uversion} -a1

%build
# Needs to be in %%build so that system_libs stays in scope
system_libs=""
for lib in freetype glew libogg libpng libtheora libvorbis libwebp openssl opus zlib; do
    system_libs+="builtin_"$lib"=no "
    rm -rf thirdparty/$lib
done
%define _scons %scons CCFLAGS="%{optflags}" LINKFLAGS="%{ldflags}" $system_libs

export BUILD_REVISION="mageia"

# Build graphical editor (tools)
%_scons p=x11 tools=yes target=release_debug

# Build game runner (without tools)
%_scons p=x11 tools=no target=release

%if %{with server}
# Build headless version of the editor
%_scons p=server tools=yes target=release_debug
%endif

%install
install -d %{buildroot}%{_bindir}
install -m755 bin/%{name}.x11.opt.tools.%{__isa_bits} %{buildroot}%{_bindir}/%{name}
install -m755 bin/%{name}.x11.opt.%{__isa_bits} %{buildroot}%{_bindir}/%{name}-runner
%if %{with server}
install -m755 bin/%{name}_server.server.opt.tools.%{__isa_bits} %{buildroot}%{_bindir}/%{name}-server
%endif

install -d %{buildroot}%{_datadir}/%{name}
cp -a godot-demo-projects-%{uversion} %{buildroot}%{_datadir}/%{name}/demos

install -D -m644 icon.svg \
    %{buildroot}%{_iconsdir}/hicolor/scalable/apps/%{name}.svg

install -d %{buildroot}%{_datadir}/applications
cat << EOF > %{buildroot}%{_datadir}/applications/%{name}.desktop
[Desktop Entry]
Name=Godot Engine
GenericName=Libre game engine
Comment=Multi-platform 2D and 3D game engine with a feature rich editor
Exec=%{name} -pm
Icon=%{name}
Terminal=false
Type=Application
Categories=Development;IDE;
EOF


%changelog
* Tue Apr 11 2017 akien <akien> 2.1.3-1.mga6
+ Revision: 1096424
- Version 2.1.3

* Sat Jan 21 2017 akien <akien> 2.1.2-1.mga6
+ Revision: 1082732
- Version 2.1.2-stable

* Wed Nov 16 2016 akien <akien> 2.1.1-1.mga6
+ Revision: 1067563
- Version 2.1.1
- Unbundle libraries thanks to upstream work to facilitate this:
  freetype, glew, libogg, libpng, libtheora, libvorbis, libwebp, openssl, opus, zlib
- Drop packaged templates for x11 32-bit and 64-bit
  o It was too much work for building templates just for Linux, and 32-bit systems
    would not have had access to the 64-bit templates anyway.
  o Godot 3.0 (next major) will let users download official templates directly,
    which is much better for the many supported platforms the Linux editor can
    export to.

* Tue Aug 09 2016 akien <akien> 2.1-1.mga6
+ Revision: 1045186
- Enable conditional server build, for testing purposes
- Sync new 2.1 tarball
- Add tarball for demos, provided separately upstream
- Version 2.1
  o BRs xrandr for dpi detection
  o No longer links statically against stdc++-static

* Sun Jul 10 2016 akien <akien> 2.0.4.1-1.mga6
+ Revision: 1040624
- Version 2.0.4.1, hotfix for a regression
- Version 2.0.4

* Thu Jun 16 2016 akien <akien> 2.0.3-4.mga6
+ Revision: 1021639
- Fix Comment in desktop file
- Force starting the project manager in the desktop file

* Tue May 17 2016 akien <akien> 2.0.3-3.mga6
+ Revision: 1016575
- Resync tarball with upstream, makes Patch0 obsolete

* Fri May 13 2016 akien <akien> 2.0.3-2.mga6
+ Revision: 1014571
- Patch upstream regression in ItemList

* Fri May 13 2016 akien <akien> 2.0.3-1.mga6
+ Revision: 1014421
- Version 2.0.3
- No longer compress templates with upx

* Tue Mar 08 2016 akien <akien> 2.0.1-1.mga6
+ Revision: 987284
- Version 2.0.1

* Wed Mar 02 2016 umeabot <umeabot> 2.0-3.mga6
+ Revision: 983443
- Rebuild for openssl

* Sat Feb 27 2016 akien <akien> 2.0-2.mga6
+ Revision: 979993
- Install demos (in a separate package)
- Set build revision to mageia instead of custom_build
- Use Mageia optflags and linkflags for builds (apart from debug template, no optflags)

* Tue Feb 23 2016 akien <akien> 2.0-1.mga6
+ Revision: 977125
- Version 2.0-stable

* Sun Feb 21 2016 akien <akien> 2.0-0.dev.1.mga6
+ Revision: 975107
- imported package godot

